import React from 'react'
import { get } from 'lodash'
import { compose } from 'recompose'
import styled from 'styled-components'
import { reduxForm } from 'redux-form'
import { th } from '@pubsweet/ui-toolkit'
import { required } from 'xpub-validators'
import { Button, Menu, ValidatedField } from '@pubsweet/ui'
import { withModal } from 'pubsweet-component-modal/src/components'

import {
  Row,
  Item,
  Label,
  Textarea,
  MultiAction,
  ContextualBox,
  ItemOverrideAlert,
  withFetching,
} from '../'

const ManuscriptEicDecision = ({
  isFetching,
  formValues,
  handleSubmit,
  messagesLabel,
  options = [],
  ...rest
}) => (
  <ContextualBox
    data-test-id="your-editorial-decision-id"
    label="Your Editorial Decision"
    {...rest}
  >
    <Root>
      <Row justify="flex-start">
        <ItemOverrideAlert flex={0} vertical>
          <Label required>Decision</Label>
          <ValidatedField
            component={input => <Menu {...input} options={options} />}
            name="decision"
            validate={[required]}
          />
        </ItemOverrideAlert>
      </Row>

      <Row mt={2}>
        <Item vertical>
          <Label required>
            {
              messagesLabel[
                get(formValues, 'decision', 'return-to-handling-editor')
              ]
            }
          </Label>
          <ValidatedField
            component={ValidatedTextArea}
            name="message"
            validate={[required]}
          />
        </Item>
      </Row>

      <Row justify="flex-end" mt={4}>
        <Button onClick={handleSubmit} primary size="medium">
          SUBMIT DECISION
        </Button>
      </Row>
    </Root>
  </ContextualBox>
)

export default compose(
  withFetching,
  withModal(({ isFetching }) => ({
    isFetching,
    modalKey: 'eic-decision',
    modalComponent: MultiAction,
  })),
  reduxForm({
    form: 'eic-decision',
    onSubmit: (
      values,
      dispatch,
      { submitDecision, showModal, setFetching },
    ) => {
      showModal({
        title: 'Are you sure you want to submit this decision?',
        onConfirm: modalProps => {
          submitDecision(values, { ...modalProps, setFetching })
        },
      })
    },
  }),
)(ManuscriptEicDecision)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  padding: ${th('gridUnit')};
`

const ValidatedTextArea = styled(Textarea)`
  & + div {
    margin-top: 0;
  }
`
// #endregion
